@@ -9,13 +9,6 @@ from Classes import *
 from pearlUpdate import *
 from checkAPT import *
 
-# Test if the distribution EOL date is found
-def test_eol_is_found():
-    (is_eol, show_eol_warning, eol_date) = RefreshThread.get_eol_status()
-    assert isinstance(eol_date, datetime)
-    assert eol_date
-    assert eol_date.year > 2010
-
 # Test KernelVersion object
 def test_kernel_version_series_comparison():
     version1 = KernelVersion ("4.8.0-2-generic")
